@@ -322,9 +322,9 @@ class AuthorityKeyIdentifier(Extension):
                 authority_cert_issuer.append(general_name._string_dict())
             ret["Authority Cert Issuer"] = authority_cert_issuer
         if self.authority_cert_serial_number is not None:
-            ret[
-                "Authority Cert Serial Number"
-            ] = self.authority_cert_serial_number
+            ret["Authority Cert Serial Number"] = (
+                self.authority_cert_serial_number
+            )
 
         if ret:
             return {self.name: ret}
@@ -945,13 +945,13 @@ class PolicyConstraints(Extension):
         ret = {self.name: {}}
 
         if self.require_explicit_policy is not None:
-            ret[self.name][
-                "Require Explicit Policy"
-            ] = self.require_explicit_policy
+            ret[self.name]["Require Explicit Policy"] = (
+                self.require_explicit_policy
+            )
         if self.inhibit_policy_mapping is not None:
-            ret[self.name][
-                "Inhibit Policy Mapping"
-            ] = self.inhibit_policy_mapping
+            ret[self.name]["Inhibit Policy Mapping"] = (
+                self.inhibit_policy_mapping
+            )
 
         return ret
 
@@ -1210,9 +1210,9 @@ class DistributionPoint(CryptoParser):
             for full_name in self.full_name:
                 ret["Full Name"].append(full_name._string_dict())
         if self.name_relative_to_crl_issuer is not None:
-            ret[
-                "Name Relative To CRL Issuer"
-            ] = self.name_relative_to_crl_issuer._string_dict()
+            ret["Name Relative To CRL Issuer"] = (
+                self.name_relative_to_crl_issuer._string_dict()
+            )
         if self.reasons is not None:
             ret["Reasons"] = []
             for reason in self.reasons:
